#!/bin/bash

ym=`date +%Y-%m`
day=`date +%d`
hm=`date +%H%M`

dbname=whois
export PATH="/usr/share/whoisd:$PATH"

declare -a filename
declare -a status
declare -a source

if [ -z "$1" ]
then
	removeIfSucceed=1
	file_bfh=BFH/$ym-$day-$hm.html
	file_tep=TEP/$ym-$day-$hm.html
	url_bfh=http://www.domain.hu/domain/varolista/ido.html
	url_tep=http://www.domain.hu/domain/parkolas/ido.html

	set -e
	cd /var/lib/whoisd/announcements/hureg
	for dir in `dirname $file_bfh` `dirname $file_tep`
	do
		[ -d "$dir" ] || mkdir -p "$dir"
	done
	set +e

	curl -sS "$url_bfh" >$file_bfh
	filename+=($file_bfh)
	status+=(BFH)
	source+=("$url_bfh")

	curl -sS "$url_tep" >$file_tep
	filename+=($file_tep)
	status+=(TEP)
	source+=("$url_tep")
	
else
	removeIfSucceed=0
	while [ $# -ge 3 ]
	do
		filename+=("$1")
		shift
		status+=("$1")
		shift
		source+=("$1")
		shift
	done
	if [ -n "$1" ]
	then
		echo "Usage: $0 [<filePath> <statusCode> <source> [<f> <c> <s> [...]]]" >&2
		exit 1
	fi
fi


for n in ${!filename[@]}
do
	file1=${filename[$n]}
	status1=${status[$n]}
	source1=${source[$n]}
	
	if grep -q "charset=iso-8859-2" "$file1" && ! grep -q "BEGIN WAYBACK TOOLBAR INSERT" "$file1"
	then
		iconv -f latin2 -t utf8 "$file1"
	else
		cat "$file1"
	fi |\
	hureg_announcements.pl "$dbname" "$status1" "$source1"
	
	if [ "${PIPESTATUS[*]}" = "0 0" ]
	then
		echo "Process $file1 OK"
		if [ $removeIfSucceed = 1 ]
		then
			rm "$file1"
		fi
	else
		echo "Process $file1 ERROR"
	fi
done

